var searchData=
[
  ['offerstate',['OfferState',['../classQXmppTransferJob.html#aab5bb06ca0d2c4f1fac33b7012d1c14fa0f5f5eec8a95f2faf27186dfd502f581',1,'QXmppTransferJob']]],
  ['online',['Online',['../classQXmppPresence_1_1Status.html#abd5503736600af94925c0a2aa988f459a5e05b60eb037c79b46984eee55c45409',1,'QXmppPresence::Status']]],
  ['openmode',['openMode',['../classQXmppRtpVideoChannel.html#a35a18db3dd09e978e80782410c5f9ab8',1,'QXmppRtpVideoChannel']]],
  ['operator_3d',['operator=',['../classQXmppDataForm_1_1Field.html#a53c05474d49892a70be0b78623f91d58',1,'QXmppDataForm::Field::operator=()'],['../classQXmppDataForm.html#a9ddc279a4bf7d8af83b9b036a1a05e3f',1,'QXmppDataForm::operator=()'],['../classQXmppConfiguration.html#a81cb2c0461d396b1458191e5181ba34a',1,'QXmppConfiguration::operator=()']]],
  ['operator_3d_3d',['operator==',['../classQXmppJinglePayloadType.html#ab368f65404568832f8cd861d2b307a94',1,'QXmppJinglePayloadType']]],
  ['options',['options',['../classQXmppDataForm_1_1Field.html#a9caa3cf1de4d1cfeb27d601cab3990d4',1,'QXmppDataForm::Field']]],
  ['os',['os',['../classQXmppVersionIq.html#a38ea1a7fb98453b7aa9783d7ba198ae7',1,'QXmppVersionIq']]],
  ['outgoingdirection',['OutgoingDirection',['../classQXmppCall.html#a429a4f8065136068b6d936cb2c803175a4959a53587ff3fe714b0c619dd8ba47d',1,'QXmppCall::OutgoingDirection()'],['../classQXmppTransferJob.html#a9c95a89a01357588f699e7d80c3de0b6adbfcc81360e31c1ded162fa244132bb7',1,'QXmppTransferJob::OutgoingDirection()']]]
];
